@@ -20,7 +20,9 @@
  *
  */
 
-#include <QDesktopServices>
+#include <QtGui/QDesktopServices>
+#include <QtDBus>
+
 #include "twitterbutton.h"
 
 /*! \brief TwitterButton constructor.
@@ -29,19 +31,23 @@
  */
 TwitterButton::TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphicsWidget *parent)
         : TwitterApplicationItem(parent),
-        _buttonLabel(buttonLabel)
+          _loader(NULL)
 {
     _pen.setColor(QColor(15, 149, 218));
-    m_isPressed = false;
+    _isPressed = false;
+    _buttonLabel = buttonLabel;
 
     setTypeButton(buttonType);
 
-    if(buttonType == TwitterButton::Expose) {
-        connect(this, SIGNAL(released()),SLOT(_emitExposeSignal()));
-    } else if(buttonType == TwitterButton::Url) {
-        _url = _buttonLabel;
-        connect(this, SIGNAL(released()),SLOT(_openUrl()));
-    }
+    font.setFamily("Nokia Sans");
+    font.setStyle(QFont::StyleNormal);
+    font.setStyleStrategy(QFont::PreferAntialias);
+    font.setWeight(QFont::Bold);
+    font.setPixelSize(16);
+
+    // Change Orientation
+    _changeOrientation();
+    connect(QApplication::desktop(), SIGNAL(resized(int)), SLOT(_changeOrientation()));
 }
 
 /*!
@@ -49,10 +55,9 @@ TwitterButton::TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphi
  */
 void TwitterButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    if(contains(event->pos())) {
-        m_isPressed = true;
-        emit pressed();
-    }
+    if(contains(event->pos()))
+        _isPressed = true;
+
     _pen.setColor(QColor(255,255,255));
     update();
 }
@@ -67,7 +72,7 @@ void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
     _pen.setColor(QColor(15, 149, 218));
 
-    m_isPressed = false;
+    _isPressed = false;
     update();
 
     emit released();
@@ -79,10 +84,10 @@ void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 void TwitterButton::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
     if(contains(event->pos())) {
-        m_isPressed = true;
+        _isPressed = true;
         _pen.setColor(QColor(255,255,255));
     } else {
-        m_isPressed = false;
+        _isPressed = false;
         _pen.setColor(QColor(15, 149, 218));
     }
 
@@ -92,7 +97,7 @@ void TwitterButton::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 /*!
  * \brief Overridden.
  */
-QRectF TwitterButton::boundingRect() const
+QRectF TwitterButton::boundingRect(void) const
 {
     return _buttonImage.rect();
 }
@@ -106,81 +111,16 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
 {
     bool down = option->state & QStyle::State_Sunken;
 
-    if (down && m_isPressed) {
+    if (down && _isPressed) {
         painter->translate(2, 2);
-        painter->setOpacity(0.7);
-
-        switch(_buttonType) {
-            case Expose:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/expose-pressed.png");
-                break;
-            case Logout:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/logout-pressed.png");
-                break;
-            case Generic:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/generic-pressed.png");
-                break;
-            case Retweet:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/rt-pressed.png");
-                break;
-            case Reply:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/reply-pressed.png");
-                break;
-            case GoUrl:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/go-to-url-pressed.png");
-                break;
-            case Delete:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/delete-pressed.png");
-                break;
-            case Back:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/back-pressed.png");
-                break;
-            case Favorite:
-            case NoFavorite:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite-pressed.png");
-                break;
-            case More:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed.png");
-                break;
-            case Close:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/close-pressed.png");
-                break;
-            case LoginSettings:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/settings-pressed.png");
-                break;
-            case GenericDownLeft:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/down-left-pressed.png");
-                break;
-            case GenericDownRight:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/down-right-pressed.png");
-                break;
-            case Url:
-            case NewAccount:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/new-account-pressed.png");
-                break;
-            case Refresh:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/refresh-pressed.png");
-                break;
-        }
-    } else
-        _buttonSelectedImage = 0;
-
-    painter->drawPixmap(0, 0, _buttonImage);
-    painter->setOpacity(1.0);
-    painter->drawPixmap(0, 0, _buttonSelectedImage);
-
-    QFont font;
-    font.setFamily("Nokia Sans");
-    font.setStyle(QFont::StyleNormal);
-    font.setStyleStrategy(QFont::PreferAntialias);
-    font.setWeight(QFont::Bold);
-
-    font.setPixelSize(16);
+        painter->drawPixmap(0, 0, _buttonSelectedImage);
+    } else {
+        painter->drawPixmap(0, 0, _buttonImage);
+    }
 
     painter->setFont(font);
     painter->setPen(_pen);
     painter->drawText(boundingRect(), Qt::TextWordWrap | Qt::AlignCenter, _buttonLabel);
-
 }
 
 /*!
@@ -210,62 +150,111 @@ void TwitterButton::setTypeButton(int buttonType)
     switch(buttonType){
         case Expose:
             _buttonImage = QPixmap(":images/resources/buttons/expose.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/expose-pressed.png");
+            connect(this, SIGNAL(released()), SLOT(_emitExposeSignal()));
             break;
+
         case Logout:
             _buttonImage = QPixmap(":images/resources/buttons/logout.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/logout-pressed.png");
             break;
+
         case Generic:
             _buttonImage = QPixmap(":images/resources/buttons/generic.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/generic-pressed.png");
             break;
+
         case Retweet:
             _buttonImage = QPixmap(":images/resources/buttons/rt.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/rt-pressed.png");
             break;
+
         case Reply:
             _buttonImage = QPixmap(":images/resources/buttons/reply.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/reply-pressed.png");
             break;
+
         case Favorite:
             _buttonImage = QPixmap(":images/resources/buttons/favorite.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite-pressed.png");
             break;
+
         case NoFavorite:
             _buttonImage = QPixmap(":images/resources/buttons/no-favorite.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite-pressed.png");
             break;
+
         case GoUrl:
             _buttonImage = QPixmap(":images/resources/buttons/go-to-url.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/go-to-url-pressed.png");
             break;
+
         case Delete:
             _buttonImage = QPixmap(":images/resources/buttons/delete.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/delete-pressed.png");
             break;
+
         case Back:
             _buttonImage = QPixmap(":images/resources/buttons/back.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/back-pressed.png");
             break;
+
         case More:
             _buttonImage = QPixmap(":images/resources/buttons/more.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed.png");
             break;
+
         case Close:
             _buttonImage = QPixmap(":images/resources/buttons/close.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/close-pressed.png");
             break;
+
         case LoginSettings:
             _buttonImage = QPixmap(":images/resources/buttons/settings.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/settings-pressed.png");
             break;
+
         case GenericDownLeft:
             _buttonImage = QPixmap(":images/resources/buttons/down-left.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/down-left-pressed.png");
             break;
+
         case GenericDownRight:
             _buttonImage = QPixmap(":images/resources/buttons/down-right.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/down-right-pressed.png");
             break;
+
         case Url:
+            _url = _buttonLabel;
+            _buttonLabel = _shortUrl(_buttonLabel);
+            connect(this, SIGNAL(released()), SLOT(_openUrl()));
+
         case NewAccount:
             _buttonImage = QPixmap(":images/resources/buttons/new-account.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/new-account-pressed.png");
             break;
+
         case Refresh:
             _buttonImage = QPixmap(":images/resources/buttons/refresh.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/refresh-pressed.png");
+            break;
+
+        case TwitterImage:
+            _url = _buttonLabel;
+            _buttonLabel = "";
+
+            _buttonImage = QPixmap(":images/resources/buttons/photo.png");
+            _buttonSelectedImage = QPixmap(":images/resources/buttons/photo_pressed.png");
+            connect(this, SIGNAL(released()), SLOT(_emitImageUrl()));
             break;
     }
-    this->_buttonType = buttonType;
-    update();
+    _buttonType = buttonType;
+
     setGeometry(_buttonImage.rect());
     setMinimumSize(_buttonImage.size());
     setMaximumSize(_buttonImage.size());
+
+    update();
 }
 
 /*!
@@ -281,14 +270,63 @@ void TwitterButton::setLabel(QString label)
  * \brief Emits a DBus signal to Hildon Desktop who manages the app window with.
  * the task swticher when the expose button is pressed.
  */
-void TwitterButton::_emitExposeSignal()
+void TwitterButton::_emitExposeSignal(void)
 {
     QDBusConnection bus = QDBusConnection::sessionBus();
     QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
     bus.send(message);
+
+    // Hack to expose to work on portrait mode
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    if(screenGeometry.width() < screenGeometry.height()) {
+        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+        bus.send(message);
+    }
 }
 
-void TwitterButton::_openUrl()
+void TwitterButton::_emitImageUrl(void)
+{
+    emit imageUrl(_url);
+}
+
+void TwitterButton::_openUrl(void)
 {
     QDesktopServices::openUrl(_url);
 }
+
+QString TwitterButton::_shortUrl(QString url)
+{
+    if(url.length() < 30)
+        return url;
+
+    QString newUrl = url.left(13) + "..." + url.right(8);
+    return newUrl;
+}
+
+void TwitterButton::_changeOrientation(void)
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+
+    if(screenGeometry.width() > screenGeometry.height()) {
+        switch(_buttonType){
+            case More:
+                _buttonImage = QPixmap(":images/resources/buttons/more.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed.png");
+                break;
+
+            default:
+                break;
+        }
+    } else if(screenGeometry.width() < screenGeometry.height()) {
+        switch(_buttonType){
+            case More:
+                _buttonImage = QPixmap(":images/resources/buttons/more_p.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed_p.png");
+                break;
+
+            default:
+                break;
+        }
+    }
+}
