@@ -27,9 +27,8 @@
 #include <QtGui/QGraphicsSceneMouseEvent>
 #include <QtGui/QPainter>
 
-#include <QtDBus>
-
 #include "twitterapplicationitem.h"
+#include "loader.h"
 
 /*! \class TwitterButton
  * \brief TwitterButton class
@@ -43,7 +42,7 @@ public:
     enum ButtonType { Expose, Logout, Generic, Retweet, Reply, Refresh,
                       Favorite, NoFavorite, GoUrl, Delete, Back,
                       Close, More, LoginSettings, GenericDownLeft,
-                      GenericDownRight, NewAccount, Url };
+                      GenericDownRight, NewAccount, Url, TwitterImage };
 
     TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphicsWidget *parent);
     QRectF boundingRect() const;
@@ -53,7 +52,7 @@ public:
     void setMessage(QString);
 
 signals:
-    void pressed(void);
+    void imageUrl(QString);
     void released(void);
 
 public slots:
@@ -61,7 +60,10 @@ public slots:
 
 private slots:
     void _emitExposeSignal(void);
+    void _emitImageUrl(void);
     void _openUrl(void);
+    QString _shortUrl(QString);
+    void _changeOrientation(void);
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *);
@@ -69,13 +71,15 @@ protected:
     virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
 
 private:
-    QPen _pen;
-    QPixmap _buttonImage;
     QPixmap _buttonSelectedImage;
+    QPixmap _buttonImage;
     QString _buttonLabel;
+    Loader *_loader;
     int _buttonType;
+    bool _isPressed;
     QString _url;
-    bool m_isPressed;
+    QFont font;
+    QPen _pen;
 };	
 
 #endif // TWITTERBUTTON_H
