@@ -31,6 +31,7 @@
 #include "imagedownload.h"
 #include "twitterbutton.h"
 #include "kineticlist.h"
+#include "account.h"
 #include "backend.h"
 
 /*! \class TwitterTopBar
@@ -48,6 +49,7 @@ private slots:
     void _imageReady(QString);
     void _download(QString url);
     void _positions(void);
+    void _changeOrientation(void);
 
 signals:
     void changeAvatar(QString);
@@ -58,26 +60,26 @@ signals:
 
 private:
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
-    void saveImage(void);
     UserInfo getUserInformation(void);
+    void saveImage(void);
 
 private:
     QGraphicsTextItem *_name;
-    QRectF *_rect;
-    QList<QPointF> listPositions;
-    QImage defaultAvatar;
-    QImage m_avatar;
-    QImage followingImage;
-    QImage followersImage;
-    QImage tweetsImage;
+    QRectF _rect;
+    QList<QPointF> _listPositions;
+    QImage _defaultAvatar;
+    QImage _avatar;
+    QImage _followingImage;
+    QImage _followersImage;
+    QImage _tweetsImage;
     TwitterButton *_refreshButton;
     TwitterButton *_homeButton;
     TwitterButton *_mentionsButton;
     KineticList *_buttonsList;
-    UserInfo user;
-    QFont font;
+    UserInfo _user;
+    QFont _font;
     QString _imageUrl;
-    QGraphicsPixmapItem *m_settingsIco;
+    QGraphicsPixmapItem *_settingsIcon;
 
 public slots:
     void updateTopBar();
