@@ -38,9 +38,13 @@ int main (int argc, char **argv)
 
     QNetworkProxyFactory::setUseSystemConfiguration(true);
 
-    QGraphicsScene scene(0, 0, 800, 480);
+    QGraphicsScene scene;
     QGraphicsView view(&scene);
 
+    #ifdef Q_WS_MAEMO_5
+        view.setAttribute(Qt::WA_Maemo5AutoOrientation, false);
+    #endif
+
     QStateMachine machine;
     QState *loginState = new QState();
     QState *timelineState = new QState();
@@ -59,17 +63,8 @@ int main (int argc, char **argv)
     machine.addState(timelineState);
     machine.setInitialState(loginState);
 
-//    QNetworkProxy proxy;
-//    proxy.setType(QNetworkProxy::HttpProxy);
-//    proxy.setHostName("172.19.244.1");
-//    proxy.setPort(3128);
-//    proxy.setUser("indt.mikhail.gadelha");
-//    proxy.setPassword("indt.mikhail.gadelha");
-//    QNetworkProxy::setApplicationProxy(proxy);
-
     machine.start();
 
-    view.setFixedSize(800, 480);
     view.setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     view.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     view.setFrameStyle(0);
@@ -78,7 +73,6 @@ int main (int argc, char **argv)
     QPalette p = view.viewport()->palette();
     p.setColor(QPalette::Base, Qt::transparent);
     view.viewport()->setPalette(p);
-//    view.setAttribute(Qt::WA_TranslucentBackground, true);
 
     return app.exec();
 }
