@@ -53,13 +53,13 @@ public:
 
 signals:
     void done(void);
+    void lockRotation(bool);
 
 private slots:
     void _postNewUpdate(void);
     void _genericError(QString);
     void _handleFavorite(QString,bool);
     void _handleDeleteTweet(quint64);
-    void _logout(void);
     void _handleFriendship(QString, bool);
     void _updateWarning(QString);
     void _refreshWarning(QString);
