@@ -50,6 +50,7 @@ struct TWITTERAPI_EXPORT Entry
     QString originalText;
     QDateTime timestamp;
     QDateTime localTime;
+    QString parsedTime;
     bool hasInReplyToStatusId;
     quint64 inReplyToStatusId;
     QString inReplyToScreenName;
@@ -57,6 +58,7 @@ struct TWITTERAPI_EXPORT Entry
     UserInfo userInfo;
     QString source;
     int retweet_count;
+    Entry *retweeted_status;
 };
 
 Q_DECLARE_METATYPE(Entry);
