@@ -447,12 +447,16 @@ XmlParserUserInfo::XmlParserUserInfo(const QString &serviceUrl, const QString &l
             XmlParser( serviceUrl, login, Entry::DirectMessage, parent )
     {}
 
+bool XmlParserUserInfo::startDocument( void )
+{
+    data.clear();
+    entry.initialize();
+    return true;
+}
+
 bool XmlParserUserInfo::endDocument( void )
 {
-
-    if(entry.userInfo.statusesCount == 0)
-        data << entry;
-
+    data << entry;
     emit credentials(data);
     return true;
 }
